==> kubernetes-model-coordination-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/coordination/v1/LeaseSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.coordination.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import java.time.ZonedDateTime;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class LeaseSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.coordination.v1.LeaseSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.coordination.v1.LeaseSpecFluent<A>{
  public LeaseSpecFluentImpl() {
  }
  public LeaseSpecFluentImpl(io.fabric8.kubernetes.api.model.coordination.v1.LeaseSpec instance) {
    this.withAcquireTime(instance.getAcquireTime()); 
    this.withHolderIdentity(instance.getHolderIdentity()); 
    this.withLeaseDurationSeconds(instance.getLeaseDurationSeconds()); 
    this.withLeaseTransitions(instance.getLeaseTransitions()); 
    this.withRenewTime(instance.getRenewTime()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.time.ZonedDateTime acquireTime;
  private java.lang.String holderIdentity;
  private java.lang.Integer leaseDurationSeconds;
  private java.lang.Integer leaseTransitions;
  private java.time.ZonedDateTime renewTime;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.time.ZonedDateTime getAcquireTime() {
    return this.acquireTime;
  }
  public A withAcquireTime(java.time.ZonedDateTime acquireTime) {
    this.acquireTime=acquireTime; return (A) this;
  }
  public java.lang.Boolean hasAcquireTime() {
    return this.acquireTime != null;
  }
  public java.lang.String getHolderIdentity() {
    return this.holderIdentity;
  }
  public A withHolderIdentity(java.lang.String holderIdentity) {
    this.holderIdentity=holderIdentity; return (A) this;
  }
  public java.lang.Boolean hasHolderIdentity() {
    return this.holderIdentity != null;
  }
  
  /**
   * Method is deprecated. use withHolderIdentity instead.
   */
  @java.lang.Deprecated
  public A withNewHolderIdentity(java.lang.String arg0) {
    return (A)withHolderIdentity(new String(arg0));
  }
  public java.lang.Integer getLeaseDurationSeconds() {
    return this.leaseDurationSeconds;
  }
  public A withLeaseDurationSeconds(java.lang.Integer leaseDurationSeconds) {
    this.leaseDurationSeconds=leaseDurationSeconds; return (A) this;
  }
  public java.lang.Boolean hasLeaseDurationSeconds() {
    return this.leaseDurationSeconds != null;
  }
  public java.lang.Integer getLeaseTransitions() {
    return this.leaseTransitions;
  }
  public A withLeaseTransitions(java.lang.Integer leaseTransitions) {
    this.leaseTransitions=leaseTransitions; return (A) this;
  }
  public java.lang.Boolean hasLeaseTransitions() {
    return this.leaseTransitions != null;
  }
  public java.time.ZonedDateTime getRenewTime() {
    return this.renewTime;
  }
  public A withRenewTime(java.time.ZonedDateTime renewTime) {
    this.renewTime=renewTime; return (A) this;
  }
  public java.lang.Boolean hasRenewTime() {
    return this.renewTime != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LeaseSpecFluentImpl that = (LeaseSpecFluentImpl) o;
    if (acquireTime != null ? !acquireTime.equals(that.acquireTime) :that.acquireTime != null) return false;
    if (holderIdentity != null ? !holderIdentity.equals(that.holderIdentity) :that.holderIdentity != null) return false;
    if (leaseDurationSeconds != null ? !leaseDurationSeconds.equals(that.leaseDurationSeconds) :that.leaseDurationSeconds != null) return false;
    if (leaseTransitions != null ? !leaseTransitions.equals(that.leaseTransitions) :that.leaseTransitions != null) return false;
    if (renewTime != null ? !renewTime.equals(that.renewTime) :that.renewTime != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(acquireTime,  holderIdentity,  leaseDurationSeconds,  leaseTransitions,  renewTime,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-coordination-5.12.0-sources.jar: io/fabric8/kubernetes/api/model/coordination/v1/LeaseSpecFluentImpl.java <==
package io.fabric8.kubernetes.api.model.coordination.v1;

import java.lang.Integer;
import java.lang.Deprecated;
import java.time.ZonedDateTime;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class LeaseSpecFluentImpl<A extends io.fabric8.kubernetes.api.model.coordination.v1.LeaseSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.coordination.v1.LeaseSpecFluent<A>{
  public LeaseSpecFluentImpl() {
  }
  public LeaseSpecFluentImpl(io.fabric8.kubernetes.api.model.coordination.v1.LeaseSpec instance) {
    this.withAcquireTime(instance.getAcquireTime()); 
    this.withHolderIdentity(instance.getHolderIdentity()); 
    this.withLeaseDurationSeconds(instance.getLeaseDurationSeconds()); 
    this.withLeaseTransitions(instance.getLeaseTransitions()); 
    this.withRenewTime(instance.getRenewTime()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.time.ZonedDateTime acquireTime;
  private java.lang.String holderIdentity;
  private java.lang.Integer leaseDurationSeconds;
  private java.lang.Integer leaseTransitions;
  private java.time.ZonedDateTime renewTime;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.time.ZonedDateTime getAcquireTime() {
    return this.acquireTime;
  }
  public A withAcquireTime(java.time.ZonedDateTime acquireTime) {
    this.acquireTime=acquireTime; return (A) this;
  }
  public java.lang.Boolean hasAcquireTime() {
    return this.acquireTime != null;
  }
  public java.lang.String getHolderIdentity() {
    return this.holderIdentity;
  }
  public A withHolderIdentity(java.lang.String holderIdentity) {
    this.holderIdentity=holderIdentity; return (A) this;
  }
  public java.lang.Boolean hasHolderIdentity() {
    return this.holderIdentity != null;
  }
  
  /**
   * Method is deprecated. use withHolderIdentity instead.
   */
  @java.lang.Deprecated
  public A withNewHolderIdentity(java.lang.String arg0) {
    return (A)withHolderIdentity(new String(arg0));
  }
  public java.lang.Integer getLeaseDurationSeconds() {
    return this.leaseDurationSeconds;
  }
  public A withLeaseDurationSeconds(java.lang.Integer leaseDurationSeconds) {
    this.leaseDurationSeconds=leaseDurationSeconds; return (A) this;
  }
  public java.lang.Boolean hasLeaseDurationSeconds() {
    return this.leaseDurationSeconds != null;
  }
  public java.lang.Integer getLeaseTransitions() {
    return this.leaseTransitions;
  }
  public A withLeaseTransitions(java.lang.Integer leaseTransitions) {
    this.leaseTransitions=leaseTransitions; return (A) this;
  }
  public java.lang.Boolean hasLeaseTransitions() {
    return this.leaseTransitions != null;
  }
  public java.time.ZonedDateTime getRenewTime() {
    return this.renewTime;
  }
  public A withRenewTime(java.time.ZonedDateTime renewTime) {
    this.renewTime=renewTime; return (A) this;
  }
  public java.lang.Boolean hasRenewTime() {
    return this.renewTime != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LeaseSpecFluentImpl that = (LeaseSpecFluentImpl) o;
    if (acquireTime != null ? !acquireTime.equals(that.acquireTime) :that.acquireTime != null) return false;
    if (holderIdentity != null ? !holderIdentity.equals(that.holderIdentity) :that.holderIdentity != null) return false;
    if (leaseDurationSeconds != null ? !leaseDurationSeconds.equals(that.leaseDurationSeconds) :that.leaseDurationSeconds != null) return false;
    if (leaseTransitions != null ? !leaseTransitions.equals(that.leaseTransitions) :that.leaseTransitions != null) return false;
    if (renewTime != null ? !renewTime.equals(that.renewTime) :that.renewTime != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(acquireTime,  holderIdentity,  leaseDurationSeconds,  leaseTransitions,  renewTime,  additionalProperties,  super.hashCode());
  }
  
}
